import { Transform, TransformConfig } from './transform.js'
export interface BrowserConfig extends TransformConfig {
	/** Whether or not we should use color, defaults to `true`. */
	color: boolean
	/** Whether or not we should write to the browser console, defaults to `true`. */
	write: boolean
	/** The objects that tell our browser transform how to convert terminal colours into console colours */
	styles: {
		[key: string]: {
			start: string
			end: string
			value: string
		}
	}
}
/**
 * Convert human readable Caterpillar entries into browser compatible entries.
 * @example
 * ``` javascript
 * import { Logger, Human, Browser } from 'caterpillar'
 * const logger = new Logger()
 * logger.pipe(new Human()).pipe(new Browser())
 * logger.log('info', 'some', {data: 'oh yeah'}, 42)
 * ```
 */
export declare class Browser extends Transform {
	config: BrowserConfig
	constructor(opts?: Partial<BrowserConfig>)
	/**
	 * Convert a human readable Caterpillar entry into a format that browser consoles can understand.
	 * And if the `write` config property is `true` (it is by default), write the result to the browser console.
	 */
	format(message: string): string[]
}
export default Browser
//# sourceMappingURL=browser.d.ts.map
