import { LogEntry } from './logger.js'
import { Transform, TransformConfig } from './transform.js'
import * as ansi from '@bevry/ansi'
/**
 * Return the given argument.
 * Used for when there is no formatter.
 */
export declare function noop<T>(str: T): T
export interface HumanConfig extends TransformConfig {
	/** Whether or not we should use color, defaults to `true`. */
	color: boolean
	/** What log level numbers correspond to what colours */
	colors: {
		[logLevelNumber: string]: ansi.ANSIApplier
	}
}
/**
 * Convert Logger entries into human readable format.
 * @extends Transform
 * @example
 * ``` javascript
 * import { Logger, Human } from 'caterpillar'
 * const logger = new Logger()
 * const human = new Human()
 * logger.pipe(human).pipe(process.stdout)
 * logger.log('info', 'some', {data: 'oh yeah'}, 42)
 * ```
 */
export declare class Human extends Transform {
	config: HumanConfig
	constructor(opts?: Partial<HumanConfig>)
	/** Get the color for the log level */
	getColor(levelNumber: number): ansi.ANSIApplier | false
	/** Pad the left of some content if need be with the specified padding to make the content reach a certain size */
	padLeft(padding: string, size: number, content: string | number): string
	/** Convert logger entry arguments into a human readable string */
	formatArguments(args: any[]): string
	/** Convert a datetime into a human readable format */
	formatDate(datetime: Date | number | string): string
	/** Convert a logger entry into a human readable format */
	format(entry: LogEntry): string
}
export default Human
//# sourceMappingURL=human.d.ts.map
