'use strict'
var __createBinding =
	(this && this.__createBinding) ||
	(Object.create
		? function (o, m, k, k2) {
				if (k2 === undefined) k2 = k
				Object.defineProperty(o, k2, {
					enumerable: true,
					get: function () {
						return m[k]
					},
				})
		  }
		: function (o, m, k, k2) {
				if (k2 === undefined) k2 = k
				o[k2] = m[k]
		  })
var __setModuleDefault =
	(this && this.__setModuleDefault) ||
	(Object.create
		? function (o, v) {
				Object.defineProperty(o, 'default', { enumerable: true, value: v })
		  }
		: function (o, v) {
				o['default'] = v
		  })
var __importStar =
	(this && this.__importStar) ||
	function (mod) {
		if (mod && mod.__esModule) return mod
		var result = {}
		if (mod != null)
			for (var k in mod)
				if (k !== 'default' && Object.hasOwnProperty.call(mod, k))
					__createBinding(result, mod, k)
		__setModuleDefault(result, mod)
		return result
	}
var __importDefault =
	(this && this.__importDefault) ||
	function (mod) {
		return mod && mod.__esModule ? mod : { default: mod }
	}
Object.defineProperty(exports, '__esModule', { value: true })
exports.Logger = void 0
const rfc_log_levels_1 = __importStar(require('rfc-log-levels'))
const get_current_line_1 = __importDefault(require('get-current-line'))
const transform_js_1 = require('./transform.js')
/**
 * Logger.
 * This is what we write to.
 * @example Creation
 * ``` javascript
 * // Via class
 * import { Logger } from 'caterpillar'
 * const logger = new Logger()
 * ```
 */
class Logger extends transform_js_1.Transform {
	constructor(opts) {
		super(opts)
		this.config.lineOffset = opts?.lineOffset ?? {
			file: __filename,
			method: /log/i,
		}
		this.config.levels = Object.assign(
			{},
			rfc_log_levels_1.rfcLogLevels,
			{
				default: 6,
			},
			opts?.levels
		)
		this.config.lineLevel = opts?.lineLevel ?? -1
	}
	/**
	 * Takes an arguments array and tranforms it into a log entry
	 * @param args
	 */
	format(args) {
		const { lineOffset, levels, lineLevel } = this.config
		const level = args.shift()
		let levelInfo = rfc_log_levels_1.default(level, levels)
		if (levelInfo == null) {
			levelInfo = rfc_log_levels_1.default('default', levels)
			if (levelInfo == null) {
				throw new Error(
					'caterpillar: rfc-log-levels: no default log level configuration was provided'
				)
			}
			args.unshift(level)
		}
		const date = new Date().toISOString()
		const lineInfo =
			levelInfo.levelNumber <= lineLevel
				? get_current_line_1.default(lineOffset)
				: {
						line: -1,
						method: 'unknown',
						file: 'unknown',
				  }
		return Object.assign({ date, args }, levelInfo, lineInfo)
	}
	/**
	 * Log the arguments into the logger stream as formatted data with debugging information.
	 * Such that our transformers can deal with it intelligently.
	 *
	 * @example Inputs
	 * ``` javascript
	 * logger.log('note', 'this is working swell')
	 * ```
	 * ``` javascript
	 * logger.log('this', 'worked', 'swell')
	 * ```
	 *
	 * @example Results
	 * ``` json
	 * {
	 * 	"args": ["this is working swell"],
	 * 	"date": "2013-04-25T10:18:25.722Z",
	 * 	"levelNumber": 5,
	 * 	"levelName": "notice",
	 * 	"line": "59",
	 * 	"method": "Object.<anonymous>",
	 * 	"file": "/Users/balupton/some-project/calling-file.js"
	 * }
	 * ```
	 * ``` json
	 * {
	 *		"args": ["this", "worked", "well"],
	 *		"date": "2013-04-25T10:18:26.539Z",
	 *		"levelNumber": 6,
	 *		"levelName": "info",
	 *		"line": "60",
	 *		"method": "Object.<anonymous>",
	 *		"file": "/Users/balupton/some-project/calling-file.js"
	 * }
	 * ```
	 */
	log(...args) {
		this.write(args)
	}
	/** Alias for log which prefixes the error log level */
	error(...args) {
		this.write(['error', ...args])
	}
	/** Alias for log which prefixes the warn log level */
	warn(...args) {
		this.write(['warn', ...args])
	}
	/** Alias for log which prefixes the info log level */
	info(...args) {
		this.write(['info', ...args])
	}
	/** Alias for log which prefixes the debug log level */
	debug(...args) {
		this.write(['debug', ...args])
	}
}
exports.Logger = Logger
exports.default = Logger
